# Makefile for Independent JPEG Group's software

# This makefile is suitable for Unix-like systems with non-ANSI compilers.
# If you have an ANSI compiler, makefile.ansi is a better starting point.

# Read installation instructions before saying "make" !!

# The name of your C compiler:
CC= cc

# You may need to adjust these cc options:
CFLAGS= -O
# Generally, we recommend defining any configuration symbols in jconfig_h,
# NOT via -D switches here.
# However, any special defines for ansi2knr_c may be included here:
ANSI2KNRFLAGS= 

# Link-time cc options:
LDFLAGS= 

# To link any special libraries, add the necessary -l commands here.
LDLIBS= -ljpeg

# Put here the object file name for the correct system-dependent memory
# manager file.  For Unix this is usually jmemnobs_o, but you may want
# to use jmemansi_o or jmemname_o if you have limited swap space.
SYSDEPMEM= jmemnobs_o

# miscellaneous OS-dependent stuff
# linker
LN= $(CC)
# file deletion command
RM= rm -f
# file rename command
MV= ren
# library (.a) file creation command
AR= slb -cr
# second step in .a creation (use "touch" if not needed)
AR2= cp libjpeg_a win1_c68_lib_

# End of configurable options.


# source files: JPEG library proper
LIBSOURCES= jcapimin_c jcapistd_c jccoefct_c jccolor_c jcdctmgr_c jchuff_c \
        jcinit_c jcmainct_c jcmarker_c jcmaster_c jcomapi_c jcparam_c \
        jcphuff_c jcprepct_c jcsample_c jctrans_c jdapimin_c jdapistd_c \
        jdatadst_c jdatasrc_c jdcoefct_c jdcolor_c jddctmgr_c jdhuff_c \
        jdinput_c jdmainct_c jdmarker_c jdmaster_c jdmerge_c jdphuff_c \
        jdpostct_c jdsample_c jdtrans_c jerror_c jfdctflt_c jfdctfst_c \
        jfdctint_c jidctflt_c jidctfst_c jidctint_c jidctred_c jquant1_c \
        jquant2_c jutils_c jmemmgr_c
# memmgr back ends: compile only one of these into a working library
SYSDEPSOURCES= jmemansi_c jmemname_c jmemnobs_c jmemdos_c jmemmac_c
# source files: cjpeg/djpeg/jpegtran applications, also rdjpgcom/wrjpgcom
APPSOURCES= cjpeg_c djpeg_c jpegtran_c rdjpgcom_c wrjpgcom_c cdjpeg_c \
        rdcolmap_c rdswitch_c transupp_c rdppm_c wrppm_c rdgif_c wrgif_c \
        rdtarga_c wrtarga_c rdbmp_c wrbmp_c rdrle_c wrrle_c
SOURCES= $(LIBSOURCES) $(SYSDEPSOURCES) $(APPSOURCES)
# files included by source files
INCLUDES= jchuff_h jdhuff_h jdct_h jerror_h jinclude_h jmemsys_h jmorecfg_h \
        jpegint_h jpeglib_h jversion_h cdjpeg_h cderror_h transupp_h
# documentation, test, and support files
DOCS= README install.doc usage.doc cjpeg.1 djpeg.1 jpegtran.1 rdjpgcom.1 \
        wrjpgcom.1 wizard.doc example_c libjpeg.doc structure.doc \
        coderules.doc filelist.doc change.log
MKFILES= configure makefile_cfg makefile.ansi makefile.unix makefile.bcc \
        makefile.mc6 makefile.dj makefile.wat makefile.vc makelib.ds \
        makeapps.ds makeproj.mac makcjpeg.st makdjpeg.st makljpeg.st \
        maktjpeg.st makefile.manx makefile.sas makefile.mms makefile.vms \
        makvms_opt
CONFIGFILES= jconfig_cfg jconfig.bcc jconfig.mc6 jconfig.dj jconfig.wat \
        jconfig.vc jconfig.mac jconfig.st jconfig.manx jconfig.sas \
        jconfig.vms
CONFIGUREFILES= config.guess config.sub install-sh ltconfig ltmain.sh
OTHERFILES= jconfig.doc ckconfig_c ansi2knr_c ansi2knr.1 jmemdosa.asm
TESTFILES= testorig.jpg testimg.ppm testimg.bmp testimg.jpg testprog.jpg \
        testimgp.jpg
DISTFILES= $(DOCS) $(MKFILES) $(CONFIGFILES) $(SOURCES) $(INCLUDES) \
        $(CONFIGUREFILES) $(OTHERFILES) $(TESTFILES)
# library object files common to compression and decompression
COMOBJECTS= jcomapi_o jutils_o jerror_o jmemmgr_o $(SYSDEPMEM)
# compression library object files
CLIBOBJECTS= jcapimin_o jcapistd_o jctrans_o jcparam_o jdatadst_o jcinit_o \
        jcmaster_o jcmarker_o jcmainct_o jcprepct_o jccoefct_o jccolor_o \
        jcsample_o jchuff_o jcphuff_o jcdctmgr_o jfdctfst_o jfdctflt_o \
        jfdctint_o
# decompression library object files
DLIBOBJECTS= jdapimin_o jdapistd_o jdtrans_o jdatasrc_o jdmaster_o \
        jdinput_o jdmarker_o jdhuff_o jdphuff_o jdmainct_o jdcoefct_o \
        jdpostct_o jddctmgr_o jidctfst_o jidctflt_o jidctint_o jidctred_o \
        jdsample_o jdcolor_o jquant1_o jquant2_o jdmerge_o
# These objectfiles are included in libjpeg_a
LIBOBJECTS= $(CLIBOBJECTS) $(DLIBOBJECTS) $(COMOBJECTS)
# object files for sample applications (excluding library files)
COBJECTS= cjpeg_o rdppm_o rdgif_o rdtarga_o rdrle_o rdbmp_o rdswitch_o cdjpeg_o
DOBJECTS= djpeg_o wrppm_o wrgif_o wrtarga_o wrrle_o wrbmp_o rdcolmap_o \
        cdjpeg_o
TROBJECTS= jpegtran_o rdswitch_o cdjpeg_o transupp_o


all: ansi2knr libjpeg_a cjpeg djpeg jpegtran rdjpgcom wrjpgcom

# This rule causes ansi2knr to be invoked.
_c_o:
	ansi2knr $*_c T$*_c
	$(CC) $(CFLAGS) -c T$*_c
	$(RM) T$*_c $*_o
	$(MV) T$*_o $*_o

ansi2knr: ansi2knr_c
	$(CC) $(CFLAGS) $(ANSI2KNRFLAGS) -o ansi2knr ansi2knr_c

libjpeg_a: ansi2knr $(LIBOBJECTS)
	$(RM) libjpeg_a
	$(AR) libjpeg_a  $(LIBOBJECTS)
	$(AR2)libjpeg_a

cjpeg: ansi2knr $(COBJECTS)
	$(LN) $(LDFLAGS) -ocjpeg $(COBJECTS) $(LDLIBS)

djpeg: ansi2knr $(DOBJECTS)
	$(LN) $(LDFLAGS) -odjpeg $(DOBJECTS) $(LDLIBS)

jpegtran: ansi2knr $(TROBJECTS) libjpeg_a
	$(LN) $(LDFLAGS) -ojpegtran $(TROBJECTS) $(LDLIBS)

rdjpgcom: rdjpgcom_o
	$(LN) $(LDFLAGS) -ordjpgcom rdjpgcom_o $(LDLIBS)

wrjpgcom: wrjpgcom_o
	$(LN) $(LDFLAGS) -owrjpgcom wrjpgcom_o $(LDLIBS)

jconfig_h: jconfig.doc
	echo You must prepare a system-dependent jconfig_h file.
	echo Please read the installation directions in install.doc.
	exit 1

clean:
	$(RM) *_o cjpeg djpeg jpegtran libjpeg_a rdjpgcom wrjpgcom
	$(RM) ansi2knr core testout*

test: cjpeg djpeg jpegtran
	$(RM) testout*
	./djpeg -dct int -ppm -outfile testout.ppm  testorig.jpg
	./djpeg -dct int -bmp -colors 256 -outfile testout.bmp  testorig.jpg
	./cjpeg -dct int -outfile testout.jpg  testimg.ppm
	./djpeg -dct int -ppm -outfile testoutp.ppm testprog.jpg
	./cjpeg -dct int -progressive -opt -outfile testoutp.jpg testimg.ppm
	./jpegtran -outfile testoutt.jpg testprog.jpg
	cmp testimg.ppm testout.ppm
	cmp testimg.bmp testout.bmp
	cmp testimg.jpg testout.jpg
	cmp testimg.ppm testoutp.ppm
	cmp testimgp.jpg testoutp.jpg
	cmp testorig.jpg testoutt.jpg


jcapimin_o: jcapimin_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jcapistd_o: jcapistd_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jccoefct_o: jccoefct_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jccolor_o: jccolor_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jcdctmgr_o: jcdctmgr_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jdct_h
jchuff_o: jchuff_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jchuff_h
jcinit_o: jcinit_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jcmainct_o: jcmainct_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jcmarker_o: jcmarker_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jcmaster_o: jcmaster_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jcomapi_o: jcomapi_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jcparam_o: jcparam_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jcphuff_o: jcphuff_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jchuff_h
jcprepct_o: jcprepct_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jcsample_o: jcsample_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jctrans_o: jctrans_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jdapimin_o: jdapimin_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jdapistd_o: jdapistd_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jdatadst_o: jdatadst_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h
jdatasrc_o: jdatasrc_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h
jdcoefct_o: jdcoefct_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jdcolor_o: jdcolor_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jddctmgr_o: jddctmgr_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jdct_h
jdhuff_o: jdhuff_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jdhuff_h
jdinput_o: jdinput_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jdmainct_o: jdmainct_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jdmarker_o: jdmarker_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jdmaster_o: jdmaster_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jdmerge_o: jdmerge_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jdphuff_o: jdphuff_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jdhuff_h
jdpostct_o: jdpostct_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jdsample_o: jdsample_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jdtrans_o: jdtrans_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jerror_o: jerror_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jversion_h jerror_h
jfdctflt_o: jfdctflt_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jdct_h
jfdctfst_o: jfdctfst_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jdct_h
jfdctint_o: jfdctint_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jdct_h
jidctflt_o: jidctflt_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jdct_h
jidctfst_o: jidctfst_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jdct_h
jidctint_o: jidctint_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jdct_h
jidctred_o: jidctred_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jdct_h
jquant1_o: jquant1_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jquant2_o: jquant2_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jutils_o: jutils_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h
jmemmgr_o: jmemmgr_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jmemsys_h
jmemansi_o: jmemansi_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jmemsys_h
jmemname_o: jmemname_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jmemsys_h
jmemnobs_o: jmemnobs_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jmemsys_h
jmemdos_o: jmemdos_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jmemsys_h
jmemmac_o: jmemmac_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h jmemsys_h
cjpeg_o: cjpeg_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h jversion_h
djpeg_o: djpeg_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h jversion_h
jpegtran_o: jpegtran_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h transupp_h jversion_h
rdjpgcom_o: rdjpgcom_c jinclude_h jconfig_h
wrjpgcom_o: wrjpgcom_c jinclude_h jconfig_h
cdjpeg_o: cdjpeg_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
rdcolmap_o: rdcolmap_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
rdswitch_o: rdswitch_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
transupp_o: transupp_c jinclude_h jconfig_h jpeglib_h jmorecfg_h jpegint_h jerror_h transupp_h
rdppm_o: rdppm_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
wrppm_o: wrppm_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
rdgif_o: rdgif_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
wrgif_o: wrgif_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
rdtarga_o: rdtarga_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
wrtarga_o: wrtarga_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
rdbmp_o: rdbmp_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
wrbmp_o: wrbmp_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
rdrle_o: rdrle_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
wrrle_o: wrrle_c cdjpeg_h jinclude_h jconfig_h jpeglib_h jmorecfg_h jerror_h cderror_h
